@@ -150,7 +150,7 @@ class EDCLineage:
         if payload is None:
             self.mu_log.log(self.mu_log.VERBOSE, "payload is None due to a previous error (see above).", module)
         else:
-            self.mu_log.log(self.mu_log.VERBOSE, "payload: " + payload, module)
+            self.mu_log.log(self.mu_log.VERBOSE, "payload: " + str(payload), module)
         return build_result, payload
 
     def build_api_load_entity_association(self):
@@ -534,6 +534,10 @@ class EDCLineage:
                 overall_result = result
                 continue
 
+            if self.settings.suppress_edc_call:
+                # when the EDC is suppressed, we also don't have any response
+                continue
+
             # Since 10.2.2HF1 an underscore is treated as OR, so we might find too many results
             json_response = response.json()
             if "metadata" in json_response:
@@ -549,9 +553,9 @@ class EDCLineage:
                                         module)
                         if item["id"] == to_attribute_id:
                             self.mu_log.log(self.mu_log.VERBOSE, "This IS the attribute we were looking for.", module)
-                        else:
-                            self.mu_log.log(self.mu_log.VERBOSE, "This is not the attribute you are looking for...",
-                                            module)
+                        # else:
+                        #    self.mu_log.log(self.mu_log.VERBOSE, "This is not the attribute you are looking for...",
+                        #                    module)
             else:
                 self.mu_log.log(self.mu_log.DEBUG, "GET did not result in an \"items\" list. And that is OK.", module)
 
@@ -633,13 +637,18 @@ class EDCLineage:
                                                          , uri="/access/2/catalog/models/attributes"
                                                          , parameters=paging_params)
 
-            if result == messages.message["ok"]:
-                json_response = response.json()
-                self.mu_log.log(self.mu_log.VERBOSE, "Call to EDC returned OK.", module)
+            if self.settings.suppress_edc_call:
+                self.mu_log.log(self.mu_log.INFO, "Call to EDC was suppressed as suppress_edc_call is True")
+                return messages.message["ok"], None
+
             else:
-                self.mu_log.log(self.mu_log.ERROR, "Call to EDC returned: " + result["code"]
-                                , module)
-                return result, None
+                if result == messages.message["ok"]:
+                    json_response = response.json()
+                    self.mu_log.log(self.mu_log.VERBOSE, "Call to EDC returned OK.", module)
+                else:
+                    self.mu_log.log(self.mu_log.ERROR, "Call to EDC returned: " + result["code"]
+                                    , module)
+                    return result, None
 
             total = json_response["metadata"]["totalCount"]
             self.mu_log.log(self.mu_log.VERBOSE, "There are >" + str(total) + "< attributes in the response."
@@ -659,8 +668,8 @@ class EDCLineage:
                                     , module)
                     found_attribute = True
                     break
-                else:
-                    self.mu_log.log(self.mu_log.VERBOSE, "This is not the attribute you are looking for...", module)
+                # else:
+                #     self.mu_log.log(self.mu_log.VERBOSE, "This is not the attribute you are looking for...", module)
 
         if found_attribute:
             return messages.message["ok"], attribute_id
